/*
 * Peony-Qt's Library
 *
 * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Meihong <hemeihong@kylinos.cn>
 *
 */

#ifndef ROTATEMENUPLUGIN_H
#define ROTATEMENUPLUGIN_H // ROTATEMENUPLUGIN_H

#include "peony-rotate-menu-plugin_global.h"
#include <menu-plugin-iface.h>
#include "../codec/kylinimagecodec/kylinimagecodec.h"
#include <QProgressBar>
namespace Peony {

class PEONYQTENGRAMPAMENUPLUGINSHARED_EXPORT RotateMenuPlugin: public QObject, public MenuPluginInterface
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID MenuPluginInterface_iid FILE "common.json")
    Q_INTERFACES(Peony::MenuPluginInterface)
public:
    explicit RotateMenuPlugin(QObject *parent = nullptr);

    PluginInterface::PluginType pluginType() override {return PluginInterface::MenuPlugin;}
    const QString name() override {return tr("Peony-Qt rotate Extension");}
    const QString description() override {return tr("rotate Menu Extension");}
    const QIcon icon() override {return QIcon::fromTheme("ukui-rotate-symbolic");}
    void setEnable(bool enable) override {m_enable = enable;}
    bool isEnable() override {return m_enable;}

    QString testPlugin() override {return "test rotate";}
    QList<QAction *> menuActions(Types types, const QString &uri, const QStringList &selectionUris) override;

    //图片类型判断
    bool is_pic_file(QString file_name);
    //图片旋转
    void rotateFun(QString imagePath, bool way);
    Mat processImage(const Mat &mat,  bool &way);
    Mat rotateRightFun(Mat mat);
    Mat rotateLeftFun(Mat mat);
    QString realFormat(const QString &path);
    void processStart(const QString &cmd, QStringList arguments);

    void processBarFun( const QStringList &Uris, int way);
    bool is_show_processBar( const QStringList &Uris);

    bool is_have_pic(const QStringList &Uris);
    bool is_write( QString imagePath );

private:
    bool m_enable;

    enum RotateWay { left, right };
    //旋转图片函数
    QString imageFormat;
    Mat imageMat;
    QPixmap imageQPix;
    QString m_imageRealFormat;
    QProcess *m_process = nullptr;
    QProgressBar *progressBar;

    int m_tiffPage = 1;
    QList<FIBITMAP *> m_fibilist ;
    QThread *m_ocrThread = nullptr;

    QList<Mat> *m_matList = nullptr;
    int m_fps = 0;
    int m_maxFrame = 0;

    QStringList m_file_type_list = {"exr", "psd",  "jfi", "jif", "jp2", "j2k", "jng", "wbmp", "xbm",
                                    "pnm", "tiff","tif", "webp", "bmp", "dib", "png", "jpg", "jpe",
                                    "jpeg", "pbm", "pgm", "ppm", "svg",  "ico", "xpm", "sr",
                                    "gif", "apng", "tga"};    // "ras",暂不支持
};

}

#endif // ROTATEMENUPLUGIN_H
